==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dss-network-plugin/translations/dss-network-plugin_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 нова порука</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 повезано</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Жичана веза</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Врућа тачка</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>ССИД</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Протокол</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Врста безбедности</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Опсег</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Сучеље</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>МАК</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>ИПв4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Мрежна маска</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основни ДНС</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>ИПв6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Брзина протока</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Уређај је онемогућен</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Повезани сте, али нема интернета</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Нисте повезани</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Мрежни кабл је ископчан</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Повезивање</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Идентификовање</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Прибављање ИП адресе</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Повезани сте</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Нисте поевзани</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>ИП сукоб</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Неуспешно</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Прибављање адресе</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Жична мрежа</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Жичана мрежа %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Бежична мрежа</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Бежична мрежа %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Уређај је онемогућен</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Мрежни кабл је ископчан</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Нисте повезани</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Повезивање</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Повезани сте, али нема интернета</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Неуспешно повезивање</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>ИП сукоб</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Искључи жичану везу</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Укључи жичану везу</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Искључи бежичану везу</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Укључи бежичану везу</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Искључи мрежу</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Укључи мрежу</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Подешавање мреже</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 нова порука</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Бежична мрежа</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Жична мрежа</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 повезано</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Повежи се на скривену мрежу</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Повежи се</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Врућа тачка</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>ССИД</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Протокол</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Врста безбедности</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Опсег</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Сучеље</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>МАК</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>ИПв4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Мрежна маска</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основни ДНС</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>ИПв6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Брзина протока</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Уређај је онемогућен</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Повезани сте, али нема интернета</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Нисте повезани</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Мрежни кабл је ископчан</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Повезивање</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Идентификовање</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Прибављање ИП адресе</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Повезани сте</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Нисте поевзани</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>ИП сукоб</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Неуспешно</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Прибављање адресе</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Жична мрежа</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Жичана мрежа %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Бежична мрежа</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Бежична мрежа %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Уређај је онемогућен</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Мрежни кабл је ископчан</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Нисте повезани</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Повезивање</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Повезани сте, али нема интернета</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Неуспешно повезивање</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>ИП сукоб</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Искључи жичану везу</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Укључи жичану везу</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Искључи бежичану везу</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Укључи бежичану везу</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Искључи мрежу</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Укључи мрежу</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Подешавање мреже</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Жичана веза</translation>
    </message>
</context>
</TS>
